import { CheckOutlined } from "@ant-design/icons";
import styles from "./index.module.css";
import { useEffect, useState } from "react";
import { isEqual } from "lodash";
import { Flex } from "antd";

interface CheckboxProps {
  value: boolean | string[];
  onChange?: (value: boolean | string[]) => void;
  options?: {
    label: string;
    value: string;
  }[];
}

const Checkbox = ({ value, onChange, options }: CheckboxProps) => {
  const [selected, setSelected] = useState<string[]>([]);

  useEffect(() => {
    if (typeof value === "object" && !isEqual(value, selected)) {
      setSelected(value);
    }
  }, [value]);

  const onclick = (params: string) => {
    if (selected.includes(params)) {
      setSelected(selected.filter((item) => item !== params));
      onChange && onChange(selected.filter((item) => item !== params));
    } else {
      setSelected([...selected, params]);
      onChange && onChange([...selected, params]);
    }
  };

  if (options && options.length > 0) {
    return (
      <div>
        {options.map((v) => {
          return (
            <Flex
              gap={12}
              align="center"
              style={{ marginBottom: 12 }}
              key={v.value}
            >
              <div
                onClick={onclick?.bind(this, v.value)}
                className={
                  selected.includes(v.value) ? styles.checked : styles.unchecked
                }
              >
                <CheckOutlined style={{ color: "#fff" }} />
              </div>
              <div>{v.label}</div>
            </Flex>
          );
        })}
      </div>
    );
  }
  if (options && options.length === 0) {
    return <div>没有可供选择的选项</div>;
  }
  return (
    <div
      onClick={onChange?.bind(this, !value)}
      className={value ? styles.checked : styles.unchecked}
    >
      <CheckOutlined style={{ color: "#fff" }} />
    </div>
  );
};

export default Checkbox;
