import { Flex, Timeline, Image } from "antd";
import DecoratePoint from "./components/decoratePoint";
import styles from "./timeLine.module.css";
import service from "@/service";
import { useEffect, useMemo, useState } from "react";
import { composeImgUrl } from "@/config/util";

interface ProcessTimeLineProps {
  detail: any;
}
const ProcessTimeLine = (props: ProcessTimeLineProps) => {
  const { detail } = props;

  const [dataSource, setDataSource] = useState<any[]>([]);

  const getData = () => {
    if (detail.type === "check") {
      setDataSource(detail.metaData?.approveHistories ?? []);
      return;
    }
    if (detail?.id) {
      service.managementService.getExamineHistory(detail.id).then((res) => {
        if (res.code === 200) {
          setDataSource(res.data);
        }
      });
    }
  };

  const items = useMemo(() => {
    return dataSource.map((v) => {
      let status = false;

      if (v.current) {
        status = true;
      }
      if (v.approveTime) {
        status = true;
      }
      const attachments = v.attachments;
      const element = (
        <div>
          <div className={styles.title}>
            {v.nodeName + " " + (v?.approveUserName ?? "")}
          </div>
          <div className={styles.time}>{v.approveTime}</div>
          {v.current && (
            <Flex
              className={styles.remake}
              align="center"
              justify="space-between"
            >
              <div style={{ color: "rgba(1, 179, 110, 1)" }}>审批中...</div>
            </Flex>
          )}
          {v?.approveComment && v.approveComment?.length > 0 && (
            <Flex
              className={styles.remake}
              align="center"
              justify="space-between"
            >
              <div>{v.approveComment}</div>
              <Flex>
                {attachments?.map((attachment: any) => {
                  let fileType = "none";
                  if (attachment && attachment.length > 0) {
                    const extra = attachment.split(".")[1];

                    if (extra === "pdf") {
                      fileType = "pdf";
                    } else if (
                      extra === "jpg" ||
                      extra === "png" ||
                      extra === "jpeg"
                    ) {
                      fileType = "img";
                    }
                  }
                  return (
                    <>
                      {fileType === "pdf" && (
                        <div
                          className={styles.noValueStatus}
                          onClick={() => {
                            window.open(composeImgUrl(attachment));
                          }}
                        >
                          pdf
                        </div>
                      )}
                      {fileType === "img" && (
                        <Image
                          width={40}
                          height={40}
                          style={{ borderRadius: 4 }}
                          src={composeImgUrl(attachment)}
                        ></Image>
                      )}
                    </>
                  );
                })}
              </Flex>
            </Flex>
          )}
        </div>
      );

      return {
        dot: <DecoratePoint type={status ? 2 : 1} />,
        children: element,
      };
    });
  }, [dataSource]);

  useEffect(() => {
    getData();
  }, [detail]);

  return (
    <div>
      <Timeline items={items} />
    </div>
  );
};

export default ProcessTimeLine;
