import {
  Button,
  Dropdown,
  Flex,
  Form,
  Input,
  MenuProps,
  Space,
  Tabs,
  message,
} from "antd";
import { useNavigate } from "react-router-dom";

import BasicModal from "@/components/BasicModal";
import avatarIcon from "@/assets/images/user/avatar.png";
import flowIcon from "@/assets/images/user/flow.png";
import styles from "./login.module.css";
import { useBoolean } from "ahooks";
import service from "@/service";
import useUserStore from "@/store/useUserStore";
import { useEffect, useState } from "react";
import { LogoutOutlined } from "@ant-design/icons";

const Login: React.FC = () => {
  const [visible, { setFalse, setTrue }] = useBoolean(false);
  const [form] = Form.useForm<{
    username: string;
    password: string;
  }>();
  const [registerForm] = Form.useForm<{
    username: string;
    password: string;
  }>();
  const { userInfo, updateUserInfo } = useUserStore();
  const [recordListNum, setRecordListNum] = useState(0);

  const navigate = useNavigate();
  const onLogin = (values: any) => {
    const params = {
      ...values,
    };
    service.loginService.onLogin(params).then((res) => {
      if (res.code === 200) {
        localStorage.setItem("applyUserInfo", JSON.stringify(res.data));
        updateUserInfo(res.data);
        setFalse();
      }
    });
  };

  const onRegister = (values: any) => {
    service.loginService.register(values).then((res) => {
      if (res.code === 200) {
        message.success("注册成功");
      }
    });
  };

  useEffect(() => {
    const mobile = userInfo?.mobile;

    if (mobile) {
      service.applyService
        .getExamineProgress({
          pageNum: 1,
          pageSize: 100,
          loginName: mobile,
        })
        .then((res) => {
          if (res.code === 200) {
            setRecordListNum(res.data.total);
          }
        });
    }
  }, [userInfo]);
  const items: MenuProps["items"] = [
    {
      key: "1",
      label: (
        <Space>
          <LogoutOutlined />
          退出登录
        </Space>
      ),
    },
  ];
  const onLogout = (item: any) => {
    if (item.key === "1") {
      updateUserInfo(undefined);
      localStorage.removeItem("applyUserInfo");
    }
  };

  const checkProgress = () => {
    if (recordListNum === 0) {
      message.info("无申请记录");
      return;
    }
    navigate("/apply-record");
  };

  return (
    <>
      {userInfo ? (
        <Space size="large">
          <div onClick={checkProgress}>
            {/* <Badge count={recordListNum}> */}
            <img src={flowIcon} alt="" style={{ width: 30, height: 32 }} />
            {/* </Badge> */}
          </div>
          <Dropdown menu={{ items, onClick: onLogout }}>
            <Space style={{ cursor: "pointer" }}>
              <Flex align="center">
                <img
                  src={avatarIcon}
                  alt=""
                  style={{ width: 55, height: 55 }}
                />
                <div>{userInfo?.username}</div>
              </Flex>
            </Space>
          </Dropdown>
        </Space>
      ) : (
        <Button onClick={setTrue} type="primary">
          登录
        </Button>
      )}

      <BasicModal
        width={1155}
        visible={visible}
        height={739}
        onClose={setFalse}
        contentStyle={{ borderRadius: 10 }}
      >
        <div className={styles.container}>
          <div></div>
          <div>
            <div className={styles.title}>欢迎登录</div>
            <div>
              <Tabs>
                <Tabs.TabPane tab="登录" key="1">
                  <Form
                    layout="vertical"
                    form={form}
                    requiredMark={false}
                    onFinish={onLogin}
                  >
                    <Form.Item
                      hasFeedback
                      label="账号"
                      name="username"
                      validateDebounce={1000}
                      rules={[{ required: true, message: "请输入账号" }]}
                    >
                      <Input placeholder="请输入账号" size="large" />
                    </Form.Item>
                    <Form.Item
                      hasFeedback
                      label="密码"
                      name="password"
                      validateDebounce={1000}
                      rules={[{ required: true, message: "请输入密码" }]}
                    >
                      <Input.Password placeholder="请输入密码" size="large" />
                    </Form.Item>
                    <Form.Item>
                      <Button
                        type="primary"
                        shape="round"
                        onClick={form.submit}
                        style={{ width: 120, height: 46 }}
                      >
                        登录
                      </Button>
                    </Form.Item>
                  </Form>
                </Tabs.TabPane>
                <Tabs.TabPane tab="注册" key="2">
                  <Form
                    layout="vertical"
                    form={registerForm}
                    requiredMark={false}
                    onFinish={onRegister}
                  >
                    <Form.Item
                      hasFeedback
                      label="账号"
                      name="phone"
                      validateDebounce={1000}
                      rules={[{ required: true, message: "请输入账号" }]}
                    >
                      <Input placeholder="请输入账号" size="large" />
                    </Form.Item>
                    <Form.Item
                      hasFeedback
                      label="密码"
                      name="password"
                      validateDebounce={1000}
                      rules={[{ required: true, message: "请输入密码" }]}
                    >
                      <Input.Password placeholder="请输入密码" size="large" />
                    </Form.Item>
                    <Form.Item>
                      <Button
                        type="primary"
                        shape="round"
                        htmlType="submit"
                        style={{ width: 120, height: 46 }}
                      >
                        注册
                      </Button>
                    </Form.Item>
                  </Form>
                </Tabs.TabPane>
              </Tabs>
            </div>
          </div>
        </div>
      </BasicModal>
    </>
  );
};

export default Login;
