import RenderComponent from "@/components/FormComponentRender/renderComponent";

import { Form, Flex } from "antd";
import { useFormContext } from "..";
import { useMemo } from "react";
import BaseFormComponent from "@/customForm/entity/base";
import { OnlyProperties } from "@/customForm/interfaces";
import { buildListByGroupId } from "@/customForm/utils";
import { PropsWithChildren } from "react";
import styles from "./formView.module.css";
import DecoratePoint from "@/pages/ApplicationMaterial/components/decoratePoint";

const GroupCard: React.FC<PropsWithChildren & { title?: string }> = (props) => {
  const { children, title } = props;
  return (
    <div className={styles.container}>
      {title && title?.length > 0 ? (
        <Flex align="center" gap={8} style={{ marginBottom: 16 }}>
          <DecoratePoint></DecoratePoint>
          <div className="">{title}</div>
        </Flex>
      ) : undefined}
      <div className={styles.card}>{children}</div>
    </div>
  );
};

const FormView = () => {
  const { formConfigList } = useFormContext();
  const getGroupName = (key: string) => {
    return config.groupList.find((v: any) => v.key === key)?.label ?? "";
  };

  const config = useMemo(() => {
    let groupList = [] as any;
    let configList = [] as any;
    if (formConfigList) {
      formConfigList.forEach((item: OnlyProperties<BaseFormComponent>) => {
        if (item.componentType === "Branch") {
          groupList.push(item);
        } else {
          configList.push(item);
        }
      });
      return {
        groupList: groupList,
        configList: buildListByGroupId(configList),
      };
    } else
      return {
        groupList: [],
        configList: [],
      };
  }, [formConfigList]);
  return (
    <Form
      colon={false}
      labelCol={{ span: 6 }}
      labelWrap
      wrapperCol={{ span: 18 }}
    >
      {config.configList.map((item: any) => {
        return (
          <GroupCard title={getGroupName(item.title)}>
            {item.list.map((formItem: any) => {
              return (
                <Form.Item
                  label={formItem.label}
                  rules={[
                    {
                      required: formItem.componentOption?.require,
                      message: `请填写${formItem?.label}`,
                    },
                    ...formItem.validationRules,
                  ]}
                  name={formItem.key}
                >
                  <RenderComponent
                    config={formItem.componentOption}
                    componentType={formItem.componentType}
                  ></RenderComponent>
                </Form.Item>
              );
            })}
          </GroupCard>
        );
      })}
    </Form>
  );
};

export default FormView;
