import type { FormComponentRegistryInfo } from "@/customForm/interfaces";
import styles from "./menu.module.css";
import { Components } from "@/customForm/registry";
import BaseFormComponent from "@/customForm/entity/base";
import { useFormContext } from "..";
import eventBus from "@/customForm/eventBus";

/**
 * tools
 */
const Menu = (props: { groupId?: string; onClick?: () => void }) => {
  let menuList = Components.meta;
  const { formConfigList, setFormConfigList } = useFormContext();
  const { groupId, onClick } = props;

  const clickHandler = (params: FormComponentRegistryInfo) => {
    const key = params.componentType;
    if (key) {
      const componentConstruct = Components.get(
        key
      ) as typeof BaseFormComponent;
      const newItem = new componentConstruct();
      if (groupId) {
        newItem.setValues({
          groupId,
        });
      }
      /** 更新默认选中 */
      eventBus.emit("add-form-item", newItem);
      setFormConfigList([...formConfigList, newItem]);
    } else throw new Error("key is undefined");
    if (onClick) onClick();
  };

  if (groupId) {
    menuList = menuList.filter((v) => v.componentType !== "Branch");
  }

  return (
    <div className={styles.container}>
      {menuList.map((item, index) => {
        return (
          <div
            key={index}
            className={styles.menuItem}
            onClick={clickHandler.bind(this, item)}
          >
            <div className={styles.btnContent}>
              <div>
                <img
                  src={item.icon}
                  alt=""
                  style={{ width: 21, height: 21 }}
                ></img>
              </div>
              {item.name}
            </div>
          </div>
        );
      })}
    </div>
  );
};

export default Menu;
